#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdarg.h>
#include <libusb-1.0/libusb.h>

/* Device Info */
#define VENDOR 0x0e4c /* Radica Games, Ltd */
#define PRODUCT 0x7288 /* Mega Byte */
#define CONFIGURATION 1
#define INTERFACE 0
#define ENDPOINT 0x81 /* IN, ID 1*/
/* Transfertype Interrupt (0x03)*/


#define TRUE  1
#define FALSE 0

#ifndef BINARY
	#define BINARY "unknown"
	#warning "BINARY was not set by Makefile"
#endif

#ifndef PROGRAM
	#define PROGRAM BINARY
	#warning "PROGRAM was not set by Makefile"
#endif

#ifndef COLORS
	#define COLORS 0
	#warning "COLORS was not set by Makefile"
#endif

#ifndef SVN_VERSION
	#define SVN_VERSION "unknown"
	#warning "SVN_VERSION was not set by Makefile"
#endif

#ifndef COMPILE_DATE
	#define COMPILE_DATE "unknown date"
	#warning "COMPILE_DATE was not set by Makefile"
#endif




#if COLORS
	#define COLOR_GREY    "\033\13301;30m"
	#define COLOR_RED     "\033\13301;31m"
	#define COLOR_GREEN   "\033\13301;32m"
	#define COLOR_YELLOW  "\033\13301;33m"
	#define COLOR_BLUE    "\033\13301;34m"
	#define COLOR_MAGENTA "\033\13301;35m"
	#define COLOR_CYAN    "\033\13301;36m"
	#define COLOR_WHITE   "\033\13301;37m"
	#define COLOR_DEFAULT "\033\13300;39m"
#else
	#define COLOR_GREY    ""
	#define COLOR_RED     ""
	#define COLOR_GREEN   ""
	#define COLOR_YELLOW  ""
	#define COLOR_BLUE    ""
	#define COLOR_MAGENTA ""
	#define COLOR_CYAN    ""
	#define COLOR_WHITE   ""
	#define COLOR_DEFAULT ""
#endif

#define COLOR_ERR COLOR_RED
#define COLOR_INFO COLOR_YELLOW
#define COLOR_DEBUG COLOR_GREEN

#define PREFIX_ERROR COLOR_DEFAULT "[" COLOR_ERR "ERROR" COLOR_DEFAULT "]"
#define PREFIX_INFO COLOR_DEFAULT "[" COLOR_INFO "INFO" COLOR_DEFAULT "] "
#define PREFIX_DEBUG COLOR_DEFAULT "[" COLOR_DEBUG "DEBUG" COLOR_DEFAULT "]"



typedef struct session_s {
	libusb_context       *context;
	libusb_device_handle *handle;
} session_t;



typedef enum debugFlags_e {
	DEBUG_EVENT=1,
	DEBUG_USB  =2,
} debugFlags_t;



/* util.c */
void Quit ( int returnCode );
int IPrintf ( char *text, ... );
int EPrintf ( int die, char *text, ... );
int DPrintf ( int debugLevel, char *text, ... );
void PrintHex ( uint8_t *data, int len );
void DebugHex ( int flags, char *caption, uint8_t *data, int len );

/* io.c  */
int findDevice( uint16_t vendor, uint16_t product );
void Dispose ( void );


/* event.c */

/* parse.c */
int parseMessage ( unsigned char *data, int len );
